// PingServerApp.java -  JMS Message Queues
import java.io.*;
import javax.jms.*;
import javax.naming.*;

public class PingServerApp implements MessageListener {
	private QueueConnection connect = null;
	private QueueSession sender, receiver;
	private QueueSender qsender;
	private QueueReceiver qreceiver;

	public PingServerApp() {
		try {
			// Setup required by both JMS consumers & producers
			InitialContext jndi = new InitialContext();
			QueueConnectionFactory factory =
				(QueueConnectionFactory)jndi.lookup
					("java:comp/env/jms/MyQueueConnectionFactory");
			connect = factory.createQueueConnection();
			Queue queue = (Queue)jndi.lookup
				("java:comp/env/jms/MyQueue");

			// JMS producer setup
			sender = connect.createQueueSession(false, 
					Session.AUTO_ACKNOWLEDGE);
			qsender = sender.createSender(queue);

			// JMS consumer setup
			receiver = connect.createQueueSession(false, 
					Session.AUTO_ACKNOWLEDGE);

			qreceiver = receiver.createReceiver(queue);
			qreceiver.setMessageListener(this);
			connect.start();
		} catch (Exception ex) {
			ex.printStackTrace();
			System.exit(1);
		}
	}

	public void sendMessage(String message) {
		try {
			TextMessage msg = sender.createTextMessage();
			msg.setText(message);
			qsender.send(msg);
			System.out.println("Sent message: " + message);
		} catch (Exception ex) {
			ex.printStackTrace();
		}
	}

	public void onMessage(Message message) {
		try {
			TextMessage msg = (TextMessage)message;
			String text = msg.getText();
			System.out.println("Received message: " + text);
		} catch (Exception ex) {
			ex.printStackTrace();
		}
	}

	public void exit() {
		try {
			if (connect != null)
				connect.close();
		} catch (Exception ex) {
			ex.printStackTrace();
			System.exit(1);
		}
		System.exit(0);
	}

	public static void main(String args[]) {
		PingServerApp ping = new PingServerApp();
		try {
			BufferedReader stdin = new
				BufferedReader(new InputStreamReader(System.in));

			while (true) {
				System.out.println("type quit to exit");
				ping.sendMessage("Test Message");
				String cmd = stdin.readLine();
				if (cmd.equals("quit")) 
					ping.exit();
			}
		} catch (Exception ex) {
			ex.printStackTrace();
		}
	}
}
