// StudentBean.java - Student Message Driven Bean

package asg.Student;

import java.io.*;
import java.rmi.*;
import javax.ejb.*;
import javax.naming.*;
import javax.jms.*;

public class StudentBean implements 
		MessageDrivenBean, MessageListener {

	private QueueConnection queueConnect = null;
	private QueueSession queueSession = null;
	private QueueSender qSender = null;

	public void 
	setMessageDrivenContext(MessageDrivenContext mdc) { }

	/****************************************************
	 * Set up queue connection and queue session objects
	 * Create queue sender object for onMessage()
	 */
	public void ejbCreate() {
		try {
			InitialContext jndi = new InitialContext();
			QueueConnectionFactory queueFactory =
				(QueueConnectionFactory)jndi.lookup
					("java:comp/env/jms/MyQueueConnectionFactory");
			queueConnect = queueFactory.createQueueConnection();
			queueSession =
				queueConnect.createQueueSession(false, 
					Session.AUTO_ACKNOWLEDGE);

			// The null argument means that the destination queue
			// will be specified by send() in onMessage()
			qSender = queueSession.createSender(null);
		} catch (Exception ex) {
			throw new EJBException(ex);
		}
	}

	public void ejbRemove() {
		try {
			if (queueConnect != null)
				queueConnect.close();
		} catch (Exception ex) {
			throw new EJBException(ex);
		}
	}

	/******************************************************
	 * Read message for course name, code, price
	 * Reply to publisher only if price is right
	 * Send course code back to publisher
	 */
	public void onMessage(Message message) {
		int MaxPrice = 500;			// Max price allowed
		try {
			StreamMessage msg = (StreamMessage)message;
			String name = msg.readString();
			String code = msg.readString();
			int price = msg.readInt();

			System.out.println("MDB received published message");
			System.out.println("\t" + name + " " + code + " " + price);

			if (price <= MaxPrice) {
				TextMessage textMsg = 
					queueSession.createTextMessage();
				textMsg.setText(code);		// store course code

				// Get Queue object sent from the publisher
				// Use QueueSender object created in ejbCreate()
				Queue sendQueue = (Queue)message.getJMSReplyTo();
				qSender.send(sendQueue, textMsg);

				// Read student database and send emails
				// to students with course name,
				// course code, and course price
				// . . .
			}
		} catch (Exception ex) {
			throw new EJBException(ex);
		}
	}
}
