// OrderApp.java -  Client for ShipOrder Bean
import java.io.*;
import java.util.*;
import javax.jms.*;
import javax.naming.*;

public class OrderApp {
	private QueueConnection connect = null;
	private QueueSession sender;
	private QueueSender qsender;

	public OrderApp() {
		try {
			InitialContext jndi = new InitialContext();
			QueueConnectionFactory factory =
				(QueueConnectionFactory)jndi.lookup
					("java:comp/env/jms/MyQueueConnectionFactory");
			connect = factory.createQueueConnection();
			Queue queue = (Queue)jndi.lookup
				("java:comp/env/jms/MyQueue");

			sender = connect.createQueueSession(false, 
					Session.AUTO_ACKNOWLEDGE);

			qsender = sender.createSender(queue);
		} catch (Exception ex) {
			ex.printStackTrace();
			System.exit(1);
		}
	}

	public void sendMessage(Calendar date) {
		try {
			ObjectMessage msg = sender.createObjectMessage();
			msg.setObject(date);
			qsender.send(msg);
			System.out.println("Sent Ship date: " + date.getTime());
		} catch (Exception ex) {
			ex.printStackTrace();
		}
	}

	public void exit() {
		try {
			if (connect != null)
				connect.close();
		} catch (Exception ex) {
			ex.printStackTrace();
			System.exit(1);
		}
		System.exit(0);
	}

	public static void main(String args[]) {
		OrderApp order = new OrderApp();
		try {
			Calendar date = new GregorianCalendar();
			order.sendMessage(date);
			order.exit();
		} catch (Exception ex) {
			ex.printStackTrace();
		}
	}
}
