// AdminClient.java
import java.util.*;
import java.text.*;
import javax.naming.Context;
import javax.naming.InitialContext;
import javax.rmi.PortableRemoteObject;
import javax.ejb.CreateException;
import asg.services.CustomerSession.*;

public class AdminClient {

	public static void main(String[] args) throws Exception {
		DecimalFormat money = new DecimalFormat("$###,###.00");
		SimpleDateFormat formatter = new SimpleDateFormat("MMM dd, yyyy");
		try {
			Context initial = new InitialContext();
			Object objref = initial.lookup("java:comp/env/ejb/CustomerSession");

			// Get a home interface object
			CustomerSessionHome home = 
				(CustomerSessionHome)PortableRemoteObject.narrow(objref, 
							  CustomerSessionHome.class);

			CustomerSession mysession = home.create();
			int count = mysession.getTotalCustomers();
			System.out.println("Total customers in database = " + count);

			// Create Customer entity bean.
			CustomerVO lydia = new CustomerVO("lydia", "Lydiapassword", "lydia@hotmail.com");
			mysession.createCustomer(lydia);
			mysession.changePassword(lydia.getName(), "NewPassword");
			mysession.identifyCustomer(lydia.getName(), "NewPassword");

			Collection customers = mysession.getCustomers();
			Iterator i = customers.iterator();
			while (i.hasNext()) {
				CustomerVO cust = (CustomerVO)i.next();
				System.out.println(cust.getName() +
					"\t" + cust.getPassword() +
					"\t" + cust.getEmail());
			}
			// this should cause an exception
			mysession.identifyCustomer(lydia.getName(), "xxx");

		} catch (CustomerIdentityException ex) {
			System.err.println(ex.getMessage());
		} catch (CreateException ex) {
			System.err.println("Error creating object." );
			System.err.println(ex.getMessage());
			System.err.println("Did you forget to re-initialize the database?");
			System.err.println("Use command: cloudscape -isql < createCustomers.sql");
		} catch (Exception ex) {
			System.err.println("Caught an unexpected exception." );
			System.err.println(ex.getMessage());
		} finally {
			System.exit(0);
		}
   } 
} // AdminClient
