// CustomerTestClient.java
import java.util.*;
import javax.naming.Context;
import javax.naming.InitialContext;
import javax.rmi.PortableRemoteObject;
import javax.ejb.CreateException;

import asg.domain.*;

public class CustomerTestClient {

	public static void main(String[] args) {
		try {
			Context initial = new InitialContext();
			Object objref = initial.lookup("java:comp/env/ejb/MyCustomer");

			// Get a home interface object
			System.out.println("get a home interface object");
			CustomerHome home = 
				(CustomerHome)PortableRemoteObject.narrow(objref, 
							  CustomerHome.class);
			System.out.println("Return from getting home interface");

			// Create Customer entity bean.
			// This generates CreateException 
			// if entity bean with primary key '150'
			// already exists.
			Customer lydia = home.create("Lydia", "Lydiapassword",
					"lydia@asgteach.com");
			
			// Call findByPrimaryKey for PK 101
			// This creates a different Customer EJB.
			Customer findPK = home.findByPrimaryKey("101");

			// Call a business method for Customer object
			// just returned
			// Must update the database
			System.out.println("Call setPassword()");
			findPK.setPassword("New Password");

			// Now call a second business method
			// using the same Customer object
			System.out.println("Call getName()");
			String name = findPK.getName();
			System.out.println("name = " + name);

			// Call finder method findAll()
			// and display information about
			// each Customer
			Collection c = home.findAll();
			Iterator i = c.iterator();
			while (i.hasNext()) {
				Customer cust = (Customer)i.next();
				System.out.println(cust.getName() + ": " + cust.getPassword());
			}

			// home method
			System.out.println(home.getTotalCustomers() + " customers in database.");
		
		} catch (CreateException ex) {
			System.err.println("Error creating object." );
			System.err.println(ex.getMessage());
		} catch (Exception ex) {
			System.err.println("Caught an unexpected exception." );
			System.err.println(ex.getMessage());
			ex.printStackTrace();
		} finally {
			System.exit(0);
		}
   } 
} // CustomerTestClient
