// CustomerBean.java

package asg.domain;

import java.sql.*;
import javax.sql.*;
import java.util.*;
import javax.ejb.*;
import javax.naming.*;

public class CustomerBean implements EntityBean {

	// Persistent data
	CustomerModel customerData;

	// Variable for DAO access
	private CustomerDAO customerDAO = null;

	// EJB variables
	private EntityContext context;
	private boolean dirty;

	// Business methods
	
	public String getCustomerID() {
		return customerData.getCustomerID();
	}
	
	public String getName() {
		return customerData.getName();
	}
	
	public void setName(String name) {
		customerData.setName(name);
		dirty = true;
	}
	
	public String getPassword() {
		return customerData.getPassword();
	}

	public void setPassword(String newPassword) {
		customerData.setPassword(newPassword);
		dirty = true;
	}
	
	public String getEmail() {
		return customerData.getEmail();
	}

	public void setEmail(String newEmail) {
		customerData.setEmail(newEmail);
		dirty = true;
	}
	
	public boolean getOrdersPending() {
		return customerData.getOrdersPending();
	}
	
	public void setOrdersPending(boolean pending) {
		customerData.setOrdersPending(pending);
		dirty = true;
	}

	// Finder methods
	
	// returns a primary key
	// or throws ObjectNotFoundException
	public String ejbFindByPrimaryKey(String primaryKey) 
		throws FinderException {

		boolean result;

		try {
			CustomerDAO dao = getDAO();
			result = dao.dbSelectByPrimaryKey(primaryKey);
		} catch (CustomerDAOSysException ex) {
			ex.printStackTrace();
			throw new EJBException("ejbFindByPrimaryKey: " + 
					ex.getMessage());
		}

		if (result) {
			return primaryKey;
		}
		else {
			throw new ObjectNotFoundException
					("Row for id " + primaryKey + " not found.");
		}
	}

	// returns a Collection of primary keys
	// or an empty Collection if no objects are found
	public Collection ejbFindByCustomerName(String name)
		throws FinderException {
		
		System.out.println("ejbFindByCustomerName(): name=" + name);
		Collection result;

		try {
			CustomerDAO dao = getDAO();
			result = dao.dbSelectByCustomerName(name);
		} catch (CustomerDAOSysException ex) {
			ex.printStackTrace();
			throw new EJBException("ejbFindByCustomerName: " + 
				ex.getMessage());
		}
		// if we don't find any matching objects,
		// result is an empty collection
		return result;
	}
	
	// returns a Collection of primary keys
	// or an empty Collection if no objects are found
	public Collection ejbFindAll()
		throws FinderException {
		
		System.out.println("ejbFindAll()");
		Collection result;

		try {
			CustomerDAO dao = getDAO();
			result = dao.dbSelectAll();
		} catch (CustomerDAOSysException ex) {
			ex.printStackTrace();
			throw new EJBException("ejbFindAll: " + 
				ex.getMessage());
		}
		// if we don't find any matching objects,
		// result is an empty collection
		return result;
	}
	
	// EJB Home Methods
	public int ejbHomeGetTotalCustomers() {
		System.out.println("ejbHomeGetTotalCustomers()");
		int result;

		try {
			CustomerDAO dao = getDAO();
			result = dao.dbCountTotalCustomers();
		} catch (CustomerDAOSysException ex) {
			ex.printStackTrace();
			throw new EJBException("ejbHomeGetTotalCustomers: " 
					+ ex.getMessage());
		}

		return result;
	}

	// EJB Methods
	
	public String ejbCreate(String name, String password, 
		String email) throws CreateException {

		System.out.println("ejbCreate(), name=" + name);
		CustomerModel newCust = null;
		try {
			CustomerDAO dao = getDAO();
			String newKey = dao.dbGetKey();
			newCust = new CustomerModel(newKey, name, password, email, false);
			dao.dbInsertCustomer(newCust);
		} catch (CustomerDAOSysException ex) {
			throw new CreateException("ejbCreate: " + 
					ex.getMessage());
		}

		// initialize persistent data
		this.customerData = newCust;
		dirty = false;
		return customerData.getCustomerID();
	}

	public void setEntityContext(EntityContext context) {
		this.context = context;
		System.out.println("setEntityContext()");
	}

	public void unsetEntityContext() {
		System.out.println("unsetEntityContext()");
	}

	public void ejbActivate() {
		System.out.println("ejbActivate()");
	}

	public void ejbPassivate() {
		customerDAO = null;
	}

	public void ejbLoad() {
		System.out.println("ejbLoad()");
		try {
			CustomerDAO dao = getDAO();
			// Get the primary key from the context
			// and refresh persistent data from database
			this.customerData = 
				dao.dbLoadCustomer((String)context.getPrimaryKey());
			dirty = false;
		} catch (CustomerDAOSysException ex) {
			ex.printStackTrace();
			throw new EJBException("ejbLoad: " +
					ex.getMessage());
		}
	}

	public void ejbStore() {
		System.out.println("ejbStore(), name=" 
				+ customerData.getName());
		try {
			if (dirty) {
				CustomerDAO dao = getDAO();
				// Synchronize the database with
				// the in-memory values of the persistent data
				dao.dbStoreCustomer(customerData);
				dirty = false;
			}
		} catch (CustomerDAOSysException ex) {
			ex.printStackTrace();
			throw new EJBException("ejbStore: " +
				ex.getMessage());
		}
	}

	public void ejbPostCreate(String name, String password, 
				String email) { 
		System.out.println("ejbPostCreate(), name=" + name);
	}

	public void ejbRemove() { 
		System.out.println("ejbRemove()");
		try {
			CustomerDAO dao = getDAO();
			dao.dbRemoveCustomer((String)context.getPrimaryKey());
		} catch (CustomerDAOSysException ex) {
			ex.printStackTrace();
			throw new EJBException("ejbRemove: " +
				ex.getMessage());
		}
	}

	private CustomerDAO getDAO() throws CustomerDAOSysException {
		if (customerDAO == null) {
			customerDAO = CustomerDAOFactory.getDAO();
		}
		return customerDAO;
	}

} // CustomerBean 
