// CustomerDAOFactory.java

package asg.domain;

import javax.naming.NamingException;
import javax.naming.InitialContext;

public class CustomerDAOFactory {

	// Instantiate a subclass that implements the abstract
	// CustomerDAO interface.
	// Obtain subclass name from the deployment descriptor

	private static CustomerDAO customerDAO = null;

	public static CustomerDAO getDAO() throws CustomerDAOSysException {
		
		String customerDAOClass = "java:comp/env/CustomerDAOClass";
		String className = null;

		if (customerDAO == null) {
			try {
				InitialContext ic = new InitialContext();
				// Lookup value of environment entry for DAO classname
				// Value is set in deployment descriptor
				className = (String) ic.lookup(customerDAOClass);

				// Instantiate class, which will provide implementation
				// for the CustomerDAO interface
				customerDAO = (CustomerDAO) Class.forName(className).newInstance();
				System.out.println(className + " instantiated.");
			} catch (Exception ex) {
				throw new CustomerDAOSysException("CustomerDAOFactory.getDAO: " +
					"NamingException for <" + className + "> DAO class : \n" 
					+ ex.getMessage());
			} 
		}
		return customerDAO;
	}
}
