// CustomerSessionBean.java

package asg.services.CustomerSession;

import java.rmi.RemoteException; 
import javax.ejb.*;
import javax.naming.*;
import java.util.*;
import asg.domain.CustomerLocalHome;
import asg.domain.CustomerLocal;

public class CustomerSessionBean implements SessionBean {

	// initialize in ejbCreate()

	private CustomerLocalHome customerHome;

	// Business methods

	// Return the number of Customers in the database
   public int getTotalCustomers() {
		return customerHome.getTotalCustomers();
	}

	// Create a new Customer in the CustomerDB
	// verify that the name is unique and the password
	// is non-empty. 

	public void createCustomer(CustomerVO customer) 
			throws CreateException, FinderException {
		if (customer.getName() == null || customer.getPassword() == null
				|| customer.getEmail() == null) {
			throw new CreateException("Customer data is null");
		}
		if (customer.getName().equals("") || customer.getPassword().equals("")
				|| customer.getEmail().equals("")) {
			throw new CreateException("Customer fields cannot be empty.");
		}

		Collection c = customerHome.findByCustomerName(customer.getName());
		if (c.size() == 0) {
			customerHome.create(
				customer.getName(), 
				customer.getPassword(),
				customer.getEmail());
		}
		else {
			System.out.println("Collection size = " + c.size());
			throw new CreateException("Customer name already in use.");
		}
	}
	
	// Change the password for the customer.
	// Make sure customer is in the database
	// Throws CustomerIdentityException if no match.
	// Throws CustomerException for other problems.

	public void changePassword(String name, String password) 
			throws CustomerIdentityException, CustomerException,
			FinderException {
		if (password.equals("")) {
			throw new CustomerException("Password cannot be empty");
		}
		Collection c = customerHome.findByCustomerName(name);
		if (c.size() == 1) {
			Iterator i=c.iterator();
			CustomerLocal cust = (CustomerLocal)i.next();
			cust.setPassword(password);
		}
		else {
			throw new CustomerIdentityException(
				"Cannot find customer " + name);
		}
	}
	
	// Change the email for the customer.
	// Make sure customer is in the database
	// Throws CustomerIdentityException if no match.
	// Throws CustomerException for other problems.

	public void changeEmail(String name, String email) 
			throws CustomerIdentityException, CustomerException,
			FinderException {
		if (email.equals("")) {
			throw new CustomerException("Email cannot be empty");
		}
		Collection c = customerHome.findByCustomerName(name);
		if (c.size() == 1) {
			Iterator i=c.iterator();
			CustomerLocal cust = (CustomerLocal)i.next();
			cust.setEmail(email);
		}
		else {
			throw new CustomerIdentityException(
						"Cannot find customer " + name);
		}
	}
	
	// Given a customer name, make sure the password
	// matches the customer's name in the database
	// Throws CustomerIdentityException if no match.

	public void identifyCustomer(String name, String password) 
			throws CustomerIdentityException, FinderException {
		
		Collection c = customerHome.findByCustomerName(name);
		if (c.size() == 1) {
			Iterator i=c.iterator();
			CustomerLocal cust = (CustomerLocal)i.next();
			if (!cust.getPassword().equals(password)) {
				throw new CustomerIdentityException(
						"Incorrect Password for customer " + name);
			}
		}
		else {
			throw new CustomerIdentityException(
					"Cannot find customer " + name);
		}
	}
	
	// Given the customer 'name', return the ordersPending field.
	// Throw CustomerIdentityException if customer
	// cannot be found.

	public boolean getOrdersPending(String name) 
			throws CustomerIdentityException, 
			FinderException {
		
		Collection c = customerHome.findByCustomerName(name);
		if (c.size() == 1) {
			Iterator i=c.iterator();
			CustomerLocal cust = (CustomerLocal)i.next();
			return cust.getOrdersPending();
		}
		else {
			throw new CustomerIdentityException(
						"Cannot find customer " + name);
		}
	}

	// Get all the customers in the customer database:
	// Return an ArrayList of CustomerVOs

	public Collection getCustomers() throws FinderException {
			
		// return an ArrayList of CustomerVOs
		ArrayList customerList = new ArrayList();
			
		Collection a = customerHome.findAll();
		Iterator i = a.iterator();
		while (i.hasNext()) {
			CustomerLocal customerEJB = (CustomerLocal)i.next();
			
			CustomerVO customer = 
				new CustomerVO(customerEJB.getName(),
					customerEJB.getPassword(),
					customerEJB.getEmail());
			customerList.add(customer);
		}
		return customerList;
	}
   
   // EJB Methods
	public CustomerSessionBean() {}
   
	public void ejbCreate() {
		try {
			Context initial = new InitialContext();
			
			// Find LocalHome Interface to CustomerEJB
			Object objref = initial.lookup("java:comp/env/ejb/Customer");
			customerHome = (CustomerLocalHome)objref;
		} catch (Exception ex) {
			ex.printStackTrace();
			throw new EJBException(ex.getMessage());
		}
	}

   public void ejbRemove() {}
   public void ejbActivate() {}
   public void ejbPassivate() {}
   public void setSessionContext(SessionContext sc) {}

} // CustomerSessionBean
