<%--
	musicCart.jsp 
	Copyright 2001-2003 Gail and Paul Anderson
	All Rights Reserved
--%>

<%--
	JSP Web component to read the Music Collection Database
	using the ValueListIterator pattern
--%>

<%--
	The following page directive tells the JSP engine to import the 
	named classes and packages when compiling the generated servlet
	code and to use "error.jsp" for an errorPage.
--%>

<%@ page import="asg.services.MusicCartEJB.*, asg.services.MusicEJB.*, java.util.*, javax.naming.Context, javax.naming.InitialContext, javax.rmi.PortableRemoteObject" errorPage="error.jsp" %>

<%--
	The following variables appear in a JSP declaration.
	They may be shared.
--%>

<%! 
	MusicIteratorHome musicHome;
	MusicCartHome cartHome;
	int customerCounter = 0;

	public void jspInit() {
		try {
			Context initial = new InitialContext();
			Object objref = initial.lookup(
					"java:comp/env/ejb/EJBMusic");
			System.out.println("lookup success for ejb/EJBMusic");
			// a reference to the home interface is shareable
			musicHome = (MusicIteratorHome)
					PortableRemoteObject.narrow(
					objref, MusicIteratorHome.class);
			System.out.println("created MusicIteratorHome object");

			objref = initial.lookup(
					"java:comp/env/ejb/MyMusicCart");
			System.out.println("lookup success for ejb/MyMusicCart");
			// a reference to the home interface is shareable
			cartHome = (MusicCartHome)
					PortableRemoteObject.narrow(objref, 
					MusicCartHome.class);
			System.out.println("created MusicCartHome object");

		} catch (Exception ex) {
			System.out.println("Unexpected Exception: " +
					ex.getMessage());
		}
	}
%>

<%
	// Initialize variables from session object
	ArrayList albums = null;
	int total = 0;
	String currentTitle = 
		(String)session.getValue("curTitle");
	if (currentTitle == null) currentTitle = "";
	String customer = 
		(String)session.getValue("customer");
	String newCustomer = 
		(String)session.getValue("newCustomer");
	MusicCart cart = 
		(MusicCart)session.getValue("musicCart");
	MusicIterator mymusic = 
		(MusicIterator)session.getValue("mymusic");
	if (cart == null || newCustomer.equals("new")) {
		// new customer; initialize music cart and
		// music iterator
		customerCounter++;
		System.out.println("New Session or Customer for " 
			+ customer);
		cart = cartHome.create(customer);
		mymusic = musicHome.create();
		mymusic.setPageSize(3);
		albums = mymusic.nextPage();
		newCustomer = "old";
		session.putValue("newCustomer", newCustomer);
		currentTitle = "";
	}
	else {
		// NOT a new customer; get list from session object
		albums = (ArrayList)session.getValue("albums");
	}
	String requestURI = request.getRequestURI();
	session.putValue("musicURL", requestURI);
	session.putValue("mymusic", mymusic);
	session.putValue("musicCart", cart);
	total = mymusic.getSize();
	// direction indicates user wants Previous or Next page
	String direction = 
		(String)request.getParameter("direction");
	if (direction == null) direction = "";

	// use MusicIterator to check status
	// and get next page
	if (direction.equals("Next") && 
				mymusic.hasMoreElements()) 
		albums = mymusic.nextPage();
	// Check status and get previous page
	else if (direction.equals("Previous") && 
				mymusic.hasPreviousElements()) 
		albums = mymusic.previousPage();
	
	// Use the current values in albums if direction does not
	// specify either "Previous" or "Next"
	// Save albums in session object
	session.putValue("albums", albums);
%>

<%--
	The following html code sets up the page to display
	the recording titles in radio buttons and invoke
	page shoppingPost.jsp with the selected user input.
--%>

<html>
<head>
<title>Music Collection Database with ValueListIterator</title>
</head>
<body bgcolor=white>
<center>
<p>
Customer <%= customer %>
<p>
You are customer number <%= customerCounter %>
<p>
<h1>Music Collection Database with ValueListIterator</h1>
<hr>
<p>
There are <%= total %> recordings
<form method="post" action="shoppingPost.jsp">
<p>
Select Music Recording:
<p>
<table border=2 cellpadding=5 bgcolor=#e0e0e0>
<%
	// Generate html radio button elements with the recording
	// titles stored in each RecordingVO element.

	String title;
	RecordingVO r;
	Iterator i = albums.iterator();
	boolean checked = false;
	int j = 1;
	while (i.hasNext()) {
		r = (RecordingVO)i.next();
		title = r.getTitle();
		// "check" the radio button if the title
		// matches the previous selection, or if it's the
		// last one and we haven't checked one yet
		if (title.equals(currentTitle) || (j == albums.size() && !checked)) {
			checked = true;
%>
			<tr><td>
			<input type="radio" name="title" value="<%=title%>" checked> <%= title %>
			</td></tr>
<%
		}
		else {
%>
			<tr><td>
			<input type="radio" name="title" value="<%=title%>" > <%= title %>
			</td></tr>
<%
		}
		j++;
	}
%>

<%--
	Provide buttons to View, Add, Delete titles
	Center them at the bottom of the table
--%>
			<tr><td align=center>
			<input TYPE="submit" NAME="View" VALUE="View Tracks">
			</td></tr>
			<tr><td align=center>
			<input TYPE="submit" NAME="Add" VALUE="Add Recording to Cart">
			</td></tr>
			<tr><td align=center>
			<input TYPE="submit" NAME="Delete" VALUE="Delete Recording from Cart">
			</td></tr>
</table>
</form>
<%--
	Provide buttons to view the previous or next page
	of recording titles
--%>
<form action="musicCart.jsp" method=get>
<input type="submit" name="direction" value="Previous">
<input type="submit" name="direction" value="Next">
</form>
<br><a href="login.jsp">Log Out</a>
</body></html>
