// AmortClient.java
import javax.naming.Context;
import javax.naming.InitialContext;
import javax.rmi.PortableRemoteObject;
import java.util.*;
import java.text.*;
import asg.LoanEJB.*;

public class AmortClient {

	public static void main(String[] args) {
		try {

			// Format monetary values with 2 places to right
			// of deceimal point, use $ sign and comma separator
			DecimalFormat money = new DecimalFormat("$###,###.00");
			// Format percentage values with 3 places 
			// to right of decimal point
			DecimalFormat percent = new DecimalFormat("##.000");
			// Format dates using 3 letter month and 4 digit year
			SimpleDateFormat date = 
				new SimpleDateFormat("MMM yyyy");

			// Get initial context and lookup coded
			// name for Loan EJB
			Context initial = new InitialContext();
			Object objref = initial.lookup("java:comp/env/ejb/MyLoan");
			// Get a handle to the home interface
			LoanHome home = 
			(LoanHome)PortableRemoteObject.narrow(objref, 
									  LoanHome.class);
			// Instantiate the Loan EJB
			Loan loanEJB = home.create();
			
			// Create a Loan Value Object with loan amount $130,000
			// interest rate of 6.85 %, and term = 15 years
			LoanVO myloan = new LoanVO(90000, 6.85, 15);

			// Invoke business method to find out monthly payment
			double monthly_payment = loanEJB.monthlyPayment(myloan);

			// Display the monthly payment information
			System.out.println("Loan Amount\t" + 
					money.format(myloan.getAmount()));
			System.out.println("Interest Rate\t" 
					+ percent.format(myloan.getRate()) + "%");
			System.out.println("Loan Term\t" + myloan.getYears() + " Years");
			System.out.println("Monthly P&I\t" 
					+ money.format(monthly_payment));

			// Get a monthly amortization table:
			ArrayList table = loanEJB.monthlyAmortTable(myloan);
			System.out.println(
				"Pay #\tMonth\tBalance\tInterest\tPrincipal\tInterest\tPrincipal");

			// Use Iterator to loop through ArrayList table	
			Iterator i = table.iterator();
			while (i.hasNext()) {
				PaymentVO p = (PaymentVO)i.next();

				// Display payment information 
				// for each PaymentVO object
				System.out.print(p.getPaymentNumber() + "\t");
				System.out.print(
					date.format(p.getPaymentDate().getTime()) + "\t");
				System.out.print(money.format(p.getBalance()) + "\t");
				System.out.print(money.format(p.getCurrentInterest()) + "\t");
				System.out.print(money.format(p.getCurrentPrincipal()) + "\t");
				System.out.print(money.format(p.getAccumInterest()) + "\t");
				System.out.print(money.format(p.getAccumPrincipal()) + "\n");
			}

			// Get an annual amortization table
			table = loanEJB.annualAmortTable(myloan);
			System.out.println(
				"Pay #\tMonth\tBalance\tInterest\tPrincipal\tInterest\tPrincipal");

			// Use Iterator to loop through ArrayList table	
			i = table.iterator();
			while (i.hasNext()) {
				PaymentVO p = (PaymentVO)i.next();
				
				// Display payment information 
				// for each PaymentVO object
				System.out.print(p.getPaymentNumber() + "\t");
				System.out.print(
					date.format(p.getPaymentDate().getTime()) + "\t");
				System.out.print(money.format(p.getBalance()) + "\t");
				System.out.print(money.format(p.getCurrentInterest()) + "\t");
				System.out.print(money.format(p.getCurrentPrincipal()) + "\t");
				System.out.print(money.format(p.getAccumInterest()) + "\t");
				System.out.print(money.format(p.getAccumPrincipal()) + "\n");
			}
		
			// Create a bad Loan Value Object to generate an exception
			myloan = new LoanVO(1000, 6.85, 0);
			// Invoke business method to find out monthly payment
			monthly_payment = loanEJB.monthlyPayment(myloan);


		} catch (LoanObjectException ex) {
			System.err.println(ex.getMessage());
		} catch (Exception ex) {
			System.err.println("Caught an unexpected exception!");
			ex.printStackTrace();
		} finally {
			System.exit(0);
		}
	} 

} // AmortClient 
