// LoanBean.java

package asg.LoanEJB;

import java.rmi.RemoteException; 
import javax.ejb.SessionBean;
import javax.ejb.SessionContext;
import java.util.*;
import java.lang.Math;

public class LoanBean implements SessionBean {

	// Private helper methods

	// Private helper method checkLoanObject makes
	// sure that the LoanVO argument is valid.
	// Valid means: interest rate is positive (> .001),
	// loan amount is positive (> $1),
	// and term is positive (> 1 year).
	// It throws LoanObjectException if there is
	// a problem.
	private void checkLoanObject(LoanVO loan)
		throws LoanObjectException {

		if (loan.getYears() < 1 || loan.getRate() < .001
				|| loan.getAmount() < 1.0) {
			throw new LoanObjectException("LoanBean: Bad LoanVO argument");
		}
	}

  	// Private helper method getPayment calculates monthly
	// principal and interest payment based on the
	// annual interest rate, term, and loan amount.
	// Called by monthlyPayment() and doAmortTable(). 
	private double getPayment(LoanVO loan) throws LoanObjectException {
		checkLoanObject(loan);
		double monthly_interest = loan.getRate() / (1200);
		int months = loan.getYears() * 12;
		return loan.getAmount() * 
			(monthly_interest / 
			(1 - Math.pow(1+monthly_interest,-1*months))) ;
   }

   // Private helper method produces an ArrayList 
	// of PaymentVO objects based on
	// values stored in LoanVO argument and the
	// requested time period.
	// Called by business methods annualAmortTable() and
	// monthlyAmortTable().
	private ArrayList doAmortTable(LoanVO loan, int time_period) 
			throws LoanObjectException {
		ArrayList table = new ArrayList();
		// this output appears on the J2EE server console
		System.out.println("table size = " + table.size());
		// Initialize all calculations to 0
		double currentInterest = 0.;
		double currentPrincipal = 0.;
		double accumInterest = 0.;
		double accumPrincipal = 0.;

		// Obtain values from LoanVO argument
		double currentBalance = loan.getAmount();
		double monthly_interest = loan.getRate() / (1200);
		int months = loan.getYears() * 12;
		// Use helper function to calculate payment
		double monthly_payment = getPayment(loan);
		Calendar curdate = loan.getStartDate();

		// Calculate payment breakdown for each
		// month for the term of the loan
		for (int i = 0; i <= months; i++) {
			if (i % time_period == 0) {
				// create a PaymentVO object
				// depending on time_period
				// and add to ArrayList
				PaymentVO p = new PaymentVO(
					i,
					curdate,
					currentBalance,
					currentInterest,
					currentPrincipal,
					accumInterest,
					accumPrincipal);
				table.add(p);	
			}
			// Update all of the calculation
			// variables
			currentInterest = currentBalance * monthly_interest;
			currentPrincipal = monthly_payment - currentInterest;
			currentBalance -= currentPrincipal;
			accumInterest += currentInterest;
			accumPrincipal += currentPrincipal;
			curdate.add(Calendar.MONTH, 1);
		}
		// Output appears on J2EE console;
		// shows new ArralyList size.
		// This number depends on term and 
		// whether client requested annual
		// or monthly amortization table.
		System.out.println("table size = " + table.size());
		return table;
   }

	// Business Methods

	// Amortization tables.  Annual table specifies
	// time period 12 (every 12 months) and
	// monthly table specifies 1 (every month).
   public ArrayList annualAmortTable(LoanVO loan) throws LoanObjectException {
   		return doAmortTable(loan, 12);
   }

   public ArrayList monthlyAmortTable(LoanVO loan) throws LoanObjectException {
   		return doAmortTable(loan, 1);
   }
   
	// Business method monthlyPayment; calls helper
	// method getPayment().
   public double monthlyPayment(LoanVO loan) throws LoanObjectException {
		return getPayment(loan);
   }

   // EJB Methods
	public LoanBean() {}
   public void ejbCreate() {}
   public void ejbRemove() {}
   public void ejbActivate() {}
   public void ejbPassivate() {}
   public void setSessionContext(SessionContext sc) {}

} // LoanBean
