<%--
	paymentPost.jsp 
	Copyright 2001-2003 Gail and Paul Anderson
	All Rights Reserved
--%>

<%--
 The following page directive tells the JSP engine to import the 
 named classes and packages when compiling the generated servlet
 code.
--%>

<%@ page import="asg.LoanEJB.*, javax.ejb.*, javax.naming.*, javax.rmi.PortableRemoteObject, java.rmi.RemoteException, java.text.*" %>

<%--
	The following declaration defines class-wide variables and
	methods jspInit() and jspDestroy().
	Recall that these declarations have class scope. 
	We must place any method declarations inside a JSP declaration. 
	
	We declare a Loan remote interface object and initialize it to null. 
	We also declare two DecimalFormat objects (money and percent)
	to format money values and percent values.

	The web server invokes jspInit() during initialization and jspDestroy()
	during shutdown.
	We put our EJB lookup() and create() calls in jspInit(), 
	making this a one-time initialization.
--%>

<%!
	private Loan loanEJB = null;
	DecimalFormat money = new DecimalFormat("$###,###.00");
	DecimalFormat percent = new DecimalFormat("##.000");

   public void jspInit() { 
      try {
         InitialContext ic = new InitialContext();
         Object objRef = ic.lookup("java:comp/env/ejb/TheLoan");
         LoanHome home = 
		 	(LoanHome)PortableRemoteObject.narrow(objRef, LoanHome.class);
         loanEJB = home.create();
      } catch (Exception ex) {
            System.out.println("Unexpected Exception: "+ ex.getMessage());
      } 
   }

   public void jspDestroy() {    
         loanEJB = null;
   }
%>

<%--
	The following scriptlet accesses the implicit session object
	to obtain the URL of the request page.
	It then accesses the implicit request object to obtain the
	user input values for the loan amount, rate, and term.
	It stores these values into the session object to use as
	the new default values in the request page.
--%>

<%
	String requestURI = (String)session.getValue("url");
	String s_amount = (String)request.getParameter("amount");
	String s_rate = (String)request.getParameter("rate");
	String s_term = (String)request.getParameter("term");
	session.putValue("amount", s_amount);
	session.putValue("rate", s_rate);
	session.putValue("term", s_term);
%>
<html>
<head>
    <title>Monthly Payment Calculator</title>
</head>

<body bgcolor=#63bdb5>
<h1><b><center>Monthly Payment Principal & Interest Result</center></b></h1>
<hr>
<%
	Double d_amount;
	Double d_rate;
	int i_term;
	String errorString = null;

	// We make sure all parameters have valid values by
	// placing the Double constructor call and Integer's
	// parseInt() call in a try block.
	// These routines generate a NumberFormatException
	// if the user input contains non-numerical characters
	// or other formatting anomalies.

	try {
		d_amount = new Double (s_amount);
		d_rate = new Double (s_rate);
		i_term = Integer.parseInt(s_term);

		// We create a LoanVO object with the user supplied
		// values and invoke our LoanEJB's business method
		// monthlyPayment().

		LoanVO myloan = new LoanVO(
			d_amount.doubleValue(), d_rate.doubleValue(), i_term);
		double monthly_payment = loanEJB.monthlyPayment(myloan);
%>
		<p>
		Amount = <%= money.format(d_amount.doubleValue()) %>
		<br>
		Rate = <%= percent.format(d_rate.doubleValue()) %> %
		<br>
		Term = <%= s_term %> Years
		<br>
		<p>
		<b>Monthly Principal & Interest is: </b>
		<%= money.format(monthly_payment) %>
		<p>
<%
	} catch (NumberFormatException ex) {
	// This is the catch handler for bad user input.
		errorString = "You have left a field empty or " +
				"specified an incorrect value for a number. " + 
				"<br>Make sure there are no special characters, commas, " + 
				"or symbols <br>embedded in the numbers.";
	} catch (LoanObjectException ex) {
	// This is the catch handler for bad LoanVO object values.
		errorString = "Loan amount must be at least 1 " +
				"<br>and rate cannot be zero.";
	}
	if (errorString != null) {
	
	// We use html formatting tags to create an error box
	// to display errorString
	// with red lettering so that it will stand out.

%>
<center>
<p STYLE="background:#bfbfbf;color:red;font-weight:normal;
	border:double thin;padding:10">
<%= errorString %>
</font>
</center>
<%
	} // end if handler
%>

<%--
 We use an expression inside the html href tag to provide
 a dynamic link to the previous request page.
--%>

<p><a href="<%= requestURI %>">
Calculate With Different Parameters</a>
</body>
</html>
