// MusicBean.java

package asg.MusicEJB;

import java.util.*;
import javax.ejb.*;
import javax.naming.*;
import java.rmi.RemoteException; 

public class MusicBean implements SessionBean {
	
	// class-wide MusicDAO object to access the data
	// MusicDAO object is instantiated in ejbCreate()
	// and provides implementation of the MusicDAO interface
	// for the particular database we're using
	private MusicDAO dao;
	
	// Business methods

	public ArrayList getMusicList() 
	{
		try {
			// Encapsulate database calls in MusicDAO
			return(dao.dbLoadMusicList());
		} catch (MusicDAOSysException ex) {
			throw new EJBException("getMusicList: " + ex.getMessage());
		}
	}

	public ArrayList getTrackList(RecordingVO rec) 
		throws NoTrackListException {

		ArrayList trackList;
		try {
			// Encapsulate database calls in MusicDAO
			trackList = dao.dbLoadTrackList(rec);
		} catch (MusicDAOSysException ex) {
			throw new EJBException("getTrackList: " + ex.getMessage());
		}
		if (trackList.size() == 0) {
			throw new NoTrackListException(
				"No Track List found for RecordingID " + rec.getRecordID());
		}
		return trackList;
	}

	// EJB methods

	public void ejbCreate() {
		try {
			// The MusicDAOFactory class returns an implementation
			// of the MusicDAO interface
			dao = MusicDAOFactory.getDAO();
		}
		catch (MusicDAOSysException ex) {
			throw new EJBException(ex.getMessage());
		}
	}

	public MusicBean() {}
	public void ejbRemove() {}
	public void ejbActivate() {}
	public void ejbPassivate() {}
	public void setSessionContext(SessionContext sc) {}

} // MusicBean
