<%--
	musicGet.jsp 
	Copyright 2001-2003 Gail and Paul Anderson
	All Rights Reserved
--%>

<%--
	JSP Web component to read the Music Collection Database using
	the Music EJB stateless session bean.  Place recording titles
	inside an HTML select component.  When user clicks the
	"View Tracks" button, invoke musicPost.jsp to display the
	track information.
--%>

<%--
	The following page directive tells the JSP engine to import the 
	named classes and packages when compiling the generated servlet
	code and to use "error.jsp" for an errorPage.
--%>

<%@ page import="asg.MusicEJB.*, java.util.*, javax.naming.Context, javax.naming.InitialContext, javax.rmi.PortableRemoteObject" errorPage="error.jsp" %>

<%--
	The following 3 variables appear in a JSP declaration.
	They appear outside the generated _jspService() method,
	which gives them class scope.

	Since we want to initialize our Music EJB object once
	and read the Music Collection database to get the
	recording titles once, we place this code inside
	method jspInit(). 
	The EJB business method getMusicList()
	returns a collection of RecordingVO objects which we
	store in ArrayList albums.
--%>

<%! 
	MusicHome musicHome;
	Music mymusic;
	ArrayList albums;

	public void jspInit() {
		try {
			Context initial = new InitialContext();
			Object objref = initial.lookup("java:comp/env/ejb/EJBMusic");
			musicHome = (MusicHome)PortableRemoteObject.narrow(
					objref, MusicHome.class);
			mymusic = musicHome.create();
			albums = mymusic.getMusicList();
		} catch (Exception ex) {
			System.out.println("Unexpected Exception: " +
					ex.getMessage());
			ex.printStackTrace();
		}
	}
%>

<%--
	The following scriptlet accesses the implicit 
	request object to obtain the current URL 
	and saves it to the session object for later retrieval.  
	It also saves variable mymusic, so we can
	make remote calls to our Music EJB, and the collection of
	RecordingVO objects.  These variables will all be available
	to other pages within the session.
--%>

<%
	String requestURI = request.getRequestURI();
	session.putValue("url", requestURI);
	session.putValue("mymusic", mymusic);
	session.putValue("albums", albums);
%>

<%--
	The following html code sets up the page to display
	the recording titles in a select element and invokes
	page musicPost.jsp with the selected user input.
--%>

<html>
<head>
<title>Music Collection Database Using EJB & JSP Version 9.7</title>
</head>
<body bgcolor=white>
<h1><b><center>Music Collection Database Using EJB & JSP</center></b></h1>
<hr>
<p>
There are <%= albums.size() %> recordings.
<form method="post" action="musicPost.jsp">
<p>
Select Music Recording:
<select name="TITLE">
<%
	// Generate html <option> elements with the recording
	// titles stored in each RecordingVO element.
	// Obtain the current title from the session object 
	// (this will be null the first time).

	String title;
	String currentTitle = (String)session.getValue("curTitle");
	if (currentTitle == null) currentTitle = "";
	RecordingVO r;
	Iterator i = albums.iterator();
	while (i.hasNext()) {
		r = (RecordingVO)i.next();
		title = r.getTitle();
		if (title.equals(currentTitle)) {
			out.println("<option selected>" + title + "</option>");
		}
		else {
			out.println("<option>" + title + "</option>");
		}
	}
%>
</select><p><p>

<%--
	Provide a "View Tracks" button to submit
	the requested title to page musicPost.jsp
--%>

<input TYPE="submit" NAME="View" VALUE="View Tracks">
</form>
</body>
</html>
