// MusicDAOFactory.java

package asg.services.MusicEJB;

import javax.naming.NamingException;
import javax.naming.InitialContext;

public class MusicDAOFactory {

	// Instantiate a subclass that implements the abstract
	// MusicDAO interface.
	// Obtain subclass name from the deployment descriptor

	private static MusicDAO musicDAO = null;

	public static MusicDAO getDAO() throws MusicDAOSysException {
		
		String musicDAOClass = "java:comp/env/MusicDAOClass";
		String className = null;
		
		if (musicDAO == null) {
			try {
				InitialContext ic = new InitialContext();
				// Lookup value of environment entry for DAO classname
				// Value is set in deployment descriptor
				className = (String) ic.lookup(musicDAOClass);

				// Instantiate class, which will provide implementation
				// for the MusicDAO interface
				musicDAO = (MusicDAO) Class.forName(className).newInstance();
				System.out.println(className + " instantiated.");
			} catch (Exception ex) {
				throw new MusicDAOSysException("MusicDAOFactory.getDAO: " +
					"NamingException for <" + className + "> DAO class : \n" 
					+ ex.getMessage());
			} 
		}
		return musicDAO;
	}
}
